@@ -3,4 +3,4 @@
 import os
 
 # Global Option which enables all internal assertions.
-ASSERTIONS = bool(int(os.environ.get("ANYTREE_ASSERTIONS", 0)))
+ASSERTIONS = bool(int(os.environ.get("ANYTREE_ASSERTIONS", "0")))
